==> thux.order-2.0.1.tar.gz: thux.order-2.0.1/thux/order/migrations/0003_auto_20161204_1436.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('l10n', '0001_initial'),
        ('product', '0006_auto_20161204_0147'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('order', '0002_auto_20161204_0928'),
    ]

    operations = [
        migrations.CreateModel(
            name='CartInvoiceAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('nominative', models.CharField(max_length=255, verbose_name='nominative')),
                ('ssn', models.CharField(max_length=16, verbose_name='social security number')),
                ('address_type', models.IntegerField(blank=True, null=True, verbose_name='type', db_index=True, choices=[(1, 'Corso'), (2, 'Largo'), (3, 'Localit\xe0'), (4, 'Piazza'), (5, 'Strada/Stretto'), (6, 'Traversa'), (7, 'Via'), (8, 'Viale'), (9, 'Vicolo/Vico'), (10, 'Circonvallazione'), (11, 'Frazione'), (12, 'Rione'), (13, 'Salita'), (14, 'Contrada'), (15, 'Statale'), (16, 'Autostrada'), (17, 'Cascina'), (18, 'Parco'), (19, 'Spalto'), (20, 'Tangenziale'), (21, 'Zona industriale'), (22, 'Borgo'), (23, 'Galleria'), (24, 'Piazzale'), (25, 'Corte'), (26, 'Centro'), (27, 'Foro'), (28, 'Lungo/Lungomare'), (29, 'Calle'), (30, 'Riviera'), (31, 'Villaggio'), (32, 'Passaggio'), (33, 'Borgata'), (34, 'Lungolago')])),
                ('name', models.CharField(db_index=True, max_length=100, verbose_name='name', blank=True)),
                ('number', models.CharField(max_length=20, verbose_name='number', db_column=b'inv_number', blank=True)),
                ('crossed', models.CharField(max_length=5, verbose_name='crossed', blank=True)),
                ('scale', models.CharField(max_length=5, verbose_name='scale', blank=True)),
                ('floor', models.CharField(max_length=3, verbose_name='floor', blank=True)),
                ('zip_code', models.CharField(db_index=True, max_length=20, verbose_name='zip code', blank=True)),
                ('locality', models.CharField(db_index=True, max_length=100, verbose_name='locality', blank=True)),
                ('province', models.CharField(db_index=True, max_length=2, verbose_name='province', blank=True)),
                ('post_office', models.CharField(max_length=10, verbose_name='post office', blank=True)),
                ('country', models.ForeignKey(related_name='cart_invoice_addresses', verbose_name='country', blank=True, to='l10n.Country', null=True)),
                ('creator', models.ForeignKey(related_name='order_cartinvoiceaddress_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartinvoiceaddress_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('user', models.ForeignKey(related_name='cart_invoice_addresses', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CartNote',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('note', models.TextField(verbose_name='note', blank=True)),
                ('creator', models.ForeignKey(related_name='order_cartnote_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartnote_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('user', models.ForeignKey(related_name='cart_notes', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'cart note',
                'verbose_name_plural': 'cart notes',
            },
        ),
        migrations.CreateModel(
            name='CartRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('quantity', models.DecimalField(verbose_name='quantity', max_digits=9, decimal_places=2)),
                ('creator', models.ForeignKey(related_name='order_cartrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('product', models.ForeignKey(related_name='cart_rows', verbose_name='product', to='product.Product')),
                ('user', models.ForeignKey(related_name='cart_rows', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('pk',),
                'verbose_name': 'cart row',
                'verbose_name_plural': 'cart rows',
            },
        ),
        migrations.CreateModel(
            name='CartShippingAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('first_name', models.CharField(max_length=255, verbose_name='first name')),
                ('last_name', models.CharField(max_length=255, verbose_name='last name')),
                ('ssn', models.CharField(max_length=16, verbose_name='social security number')),
                ('address_type', models.IntegerField(blank=True, null=True, verbose_name='type', db_index=True, choices=[(1, 'Corso'), (2, 'Largo'), (3, 'Localit\xe0'), (4, 'Piazza'), (5, 'Strada/Stretto'), (6, 'Traversa'), (7, 'Via'), (8, 'Viale'), (9, 'Vicolo/Vico'), (10, 'Circonvallazione'), (11, 'Frazione'), (12, 'Rione'), (13, 'Salita'), (14, 'Contrada'), (15, 'Statale'), (16, 'Autostrada'), (17, 'Cascina'), (18, 'Parco'), (19, 'Spalto'), (20, 'Tangenziale'), (21, 'Zona industriale'), (22, 'Borgo'), (23, 'Galleria'), (24, 'Piazzale'), (25, 'Corte'), (26, 'Centro'), (27, 'Foro'), (28, 'Lungo/Lungomare'), (29, 'Calle'), (30, 'Riviera'), (31, 'Villaggio'), (32, 'Passaggio'), (33, 'Borgata'), (34, 'Lungolago')])),
                ('name', models.CharField(db_index=True, max_length=100, verbose_name='name', blank=True)),
                ('number', models.CharField(max_length=20, verbose_name='number', db_column=b'inv_number', blank=True)),
                ('crossed', models.CharField(max_length=5, verbose_name='crossed', blank=True)),
                ('scale', models.CharField(max_length=5, verbose_name='scale', blank=True)),
                ('floor', models.CharField(max_length=3, verbose_name='floor', blank=True)),
                ('zip_code', models.CharField(db_index=True, max_length=20, verbose_name='zip code', blank=True)),
                ('locality', models.CharField(db_index=True, max_length=100, verbose_name='locality', blank=True)),
                ('province', models.CharField(db_index=True, max_length=2, verbose_name='province', blank=True)),
                ('post_office', models.CharField(max_length=10, verbose_name='post office', blank=True)),
                ('country', models.ForeignKey(related_name='cart_shipping_addresses', verbose_name='country', blank=True, to='l10n.Country', null=True)),
                ('creator', models.ForeignKey(related_name='order_cartshippingaddress_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartshippingaddress_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('user', models.ForeignKey(related_name='cart_shipping_addresses', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OrderNumber',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('year', models.PositiveIntegerField(unique=True, verbose_name='year')),
                ('last_number', models.PositiveIntegerField(verbose_name='last number')),
                ('creator', models.ForeignKey(related_name='order_ordernumber_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_ordernumber_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('-year', '-last_number'),
                'verbose_name': 'order number',
                'verbose_name_plural': 'order numbers',
                'permissions': (('list_ordernumber', 'Can list order number'),),
            },
        ),
        migrations.AlterModelOptions(
            name='order',
            options={'ordering': ('-date_p', '-number'), 'verbose_name': 'order', 'verbose_name_plural': 'orders', 'permissions': (('list_order', 'Can list order'),)},
        ),
        migrations.AlterModelOptions(
            name='orderrow',
            options={'ordering': ('-order__date_p', '-order__number', 'ordering', 'id'), 'verbose_name': 'order row', 'verbose_name_plural': 'order rows', 'permissions': (('list_orderrow', 'Can list order row'),)},
        ),
        migrations.AlterModelOptions(
            name='vatrow',
            options={'ordering': ('vat__ordering', 'vat__code'), 'verbose_name': 'vat row', 'verbose_name_plural': 'vat rows', 'permissions': (('list_vatrow', 'Can list vat row'),)},
        ),
        migrations.AlterUniqueTogether(
            name='cartrow',
            unique_together=set([('cart_token', 'user', 'product')]),
        ),
    ]

==> thux.order-2.0.2.tar.gz: thux.order-2.0.2/thux/order/migrations/0003_auto_20161204_1436.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.conf import settings


class Migration(migrations.Migration):

    dependencies = [
        ('l10n', '0001_initial'),
        ('product', '0006_auto_20161204_0147'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('order', '0002_auto_20161204_0928'),
    ]

    operations = [
        migrations.CreateModel(
            name='CartInvoiceAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('nominative', models.CharField(max_length=255, verbose_name='nominative')),
                ('ssn', models.CharField(max_length=16, verbose_name='social security number')),
                ('address_type', models.IntegerField(blank=True, null=True, verbose_name='type', db_index=True, choices=[(1, 'Corso'), (2, 'Largo'), (3, 'Localit\xe0'), (4, 'Piazza'), (5, 'Strada/Stretto'), (6, 'Traversa'), (7, 'Via'), (8, 'Viale'), (9, 'Vicolo/Vico'), (10, 'Circonvallazione'), (11, 'Frazione'), (12, 'Rione'), (13, 'Salita'), (14, 'Contrada'), (15, 'Statale'), (16, 'Autostrada'), (17, 'Cascina'), (18, 'Parco'), (19, 'Spalto'), (20, 'Tangenziale'), (21, 'Zona industriale'), (22, 'Borgo'), (23, 'Galleria'), (24, 'Piazzale'), (25, 'Corte'), (26, 'Centro'), (27, 'Foro'), (28, 'Lungo/Lungomare'), (29, 'Calle'), (30, 'Riviera'), (31, 'Villaggio'), (32, 'Passaggio'), (33, 'Borgata'), (34, 'Lungolago')])),
                ('name', models.CharField(db_index=True, max_length=100, verbose_name='name', blank=True)),
                ('number', models.CharField(max_length=20, verbose_name='number', db_column='inv_number', blank=True)),
                ('number', models.CharField(max_length=20, verbose_name='number', db_column='inv_number', blank=True)),
                ('crossed', models.CharField(max_length=5, verbose_name='crossed', blank=True)),
                ('scale', models.CharField(max_length=5, verbose_name='scale', blank=True)),
                ('floor', models.CharField(max_length=3, verbose_name='floor', blank=True)),
                ('zip_code', models.CharField(db_index=True, max_length=20, verbose_name='zip code', blank=True)),
                ('locality', models.CharField(db_index=True, max_length=100, verbose_name='locality', blank=True)),
                ('province', models.CharField(db_index=True, max_length=2, verbose_name='province', blank=True)),
                ('post_office', models.CharField(max_length=10, verbose_name='post office', blank=True)),
                ('country', models.ForeignKey(related_name='cart_invoice_addresses', verbose_name='country', blank=True, to='l10n.Country', null=True)),
                ('creator', models.ForeignKey(related_name='order_cartinvoiceaddress_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartinvoiceaddress_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('user', models.ForeignKey(related_name='cart_invoice_addresses', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='CartNote',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('note', models.TextField(verbose_name='note', blank=True)),
                ('creator', models.ForeignKey(related_name='order_cartnote_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartnote_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('user', models.ForeignKey(related_name='cart_notes', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'cart note',
                'verbose_name_plural': 'cart notes',
            },
        ),
        migrations.CreateModel(
            name='CartRow',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('quantity', models.DecimalField(verbose_name='quantity', max_digits=9, decimal_places=2)),
                ('creator', models.ForeignKey(related_name='order_cartrow_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartrow_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('product', models.ForeignKey(related_name='cart_rows', verbose_name='product', to='product.Product')),
                ('user', models.ForeignKey(related_name='cart_rows', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('pk',),
                'verbose_name': 'cart row',
                'verbose_name_plural': 'cart rows',
            },
        ),
        migrations.CreateModel(
            name='CartShippingAddress',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('cart_token', models.CharField(max_length=100, verbose_name='session key')),
                ('first_name', models.CharField(max_length=255, verbose_name='first name')),
                ('last_name', models.CharField(max_length=255, verbose_name='last name')),
                ('ssn', models.CharField(max_length=16, verbose_name='social security number')),
                ('address_type', models.IntegerField(blank=True, null=True, verbose_name='type', db_index=True, choices=[(1, 'Corso'), (2, 'Largo'), (3, 'Localit\xe0'), (4, 'Piazza'), (5, 'Strada/Stretto'), (6, 'Traversa'), (7, 'Via'), (8, 'Viale'), (9, 'Vicolo/Vico'), (10, 'Circonvallazione'), (11, 'Frazione'), (12, 'Rione'), (13, 'Salita'), (14, 'Contrada'), (15, 'Statale'), (16, 'Autostrada'), (17, 'Cascina'), (18, 'Parco'), (19, 'Spalto'), (20, 'Tangenziale'), (21, 'Zona industriale'), (22, 'Borgo'), (23, 'Galleria'), (24, 'Piazzale'), (25, 'Corte'), (26, 'Centro'), (27, 'Foro'), (28, 'Lungo/Lungomare'), (29, 'Calle'), (30, 'Riviera'), (31, 'Villaggio'), (32, 'Passaggio'), (33, 'Borgata'), (34, 'Lungolago')])),
                ('name', models.CharField(db_index=True, max_length=100, verbose_name='name', blank=True)),
                ('number', models.CharField(max_length=20, verbose_name='number', db_column='inv_number', blank=True)),
                ('crossed', models.CharField(max_length=5, verbose_name='crossed', blank=True)),
                ('scale', models.CharField(max_length=5, verbose_name='scale', blank=True)),
                ('floor', models.CharField(max_length=3, verbose_name='floor', blank=True)),
                ('zip_code', models.CharField(db_index=True, max_length=20, verbose_name='zip code', blank=True)),
                ('locality', models.CharField(db_index=True, max_length=100, verbose_name='locality', blank=True)),
                ('province', models.CharField(db_index=True, max_length=2, verbose_name='province', blank=True)),
                ('post_office', models.CharField(max_length=10, verbose_name='post office', blank=True)),
                ('country', models.ForeignKey(related_name='cart_shipping_addresses', verbose_name='country', blank=True, to='l10n.Country', null=True)),
                ('creator', models.ForeignKey(related_name='order_cartshippingaddress_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_cartshippingaddress_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('user', models.ForeignKey(related_name='cart_shipping_addresses', verbose_name='user', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='OrderNumber',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('year', models.PositiveIntegerField(unique=True, verbose_name='year')),
                ('last_number', models.PositiveIntegerField(verbose_name='last number')),
                ('creator', models.ForeignKey(related_name='order_ordernumber_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='order_ordernumber_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ('-year', '-last_number'),
                'verbose_name': 'order number',
                'verbose_name_plural': 'order numbers',
                'permissions': (('list_ordernumber', 'Can list order number'),),
            },
        ),
        migrations.AlterModelOptions(
            name='order',
            options={'ordering': ('-date_p', '-number'), 'verbose_name': 'order', 'verbose_name_plural': 'orders', 'permissions': (('list_order', 'Can list order'),)},
        ),
        migrations.AlterModelOptions(
            name='orderrow',
            options={'ordering': ('-order__date_p', '-order__number', 'ordering', 'id'), 'verbose_name': 'order row', 'verbose_name_plural': 'order rows', 'permissions': (('list_orderrow', 'Can list order row'),)},
        ),
        migrations.AlterModelOptions(
            name='vatrow',
            options={'ordering': ('vat__ordering', 'vat__code'), 'verbose_name': 'vat row', 'verbose_name_plural': 'vat rows', 'permissions': (('list_vatrow', 'Can list vat row'),)},
        ),
        migrations.AlterUniqueTogether(
            name='cartrow',
            unique_together=set([('cart_token', 'user', 'product')]),
        ),
    ]
